/*
 * Copyright (C) 2012  Christian Mollekopf <mollekopf@kolabsys.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef KOLABCALENDARING_H
#define KOLABCALENDARING_H

#ifndef SWIG
#include "kolab_export.h"
#else
/* No export/import SWIG interface files */
#define KOLAB_EXPORT
#endif

#include <kcalcore/event.h>
#include <kcalcore/memorycalendar.h>
#include <kolabevent.h>
#include <QSharedPointer>

namespace Kolab {
    namespace Calendaring {

/**
 * Dummy function to ensure the kolabcalendaring class is created in the php module.
 */
KOLAB_EXPORT void dummy();

/**
 * In-Memory Calendar Cache
 */
class KOLAB_EXPORT Calendar {
public:
    explicit Calendar();
    /**
     * Add an event to the in-memory calendar.
     */
    void addEvent(const Kolab::Event &);
    /**
     * Returns all events within the specified interval (start and end inclusive).
     *
     * @param sort controls if the resulting event set is sorted in ascending order according to the start date
     */
    std::vector<Kolab::Event> getEvents(const Kolab::cDateTime &start, const Kolab::cDateTime &end, bool sort);
private:
    Calendar(const Calendar &);
    void operator=(const Calendar &);
    QSharedPointer<KCalCore::MemoryCalendar> mCalendar;
};

    }; //Namespace
}; //Namespace

#endif
